%define pythontopver 2.3
Summary: An interpreted, interactive object-oriented programming language.
Name: python
Version: %{pythontopver}.5
Release: 6tr
License: distributable
Group: Trustix Official
Provides: python-abi = %{pythontopver}
Provides: python(abi) =  %{pythontopver}
Source0: http://www.python.org/ftp/python/%{version}/Python-%{version}.tar.bz2
Source1: python-doc-html-%{version}.tar.bz2
Patch0: python-2.3.5-pcre-CAN-2005-2491.patch
Patch1: python-CVE-2006-4980.patch
BuildRequires: zlib-devel gcc-c++-devel
Buildroot: %{_tmppath}/%{name}-root

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries.

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to RPM.

Note that documentation for Python is provided in the python-docs
package.

%package devel
Summary: The libraries and header files needed for Python development.
Requires: python = %{PACKAGE_VERSION}
Group: Trustix Official

%description devel
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install python-devel if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.

%package modules
Summary: additional python modules
Requires: python = %{PACKAGE_VERSION}
BuildRequires: ncurses-devel
PreReq: /var/lib/rpm
Requires: ncurses expat-libs
Provides: python-dbm
Obsoletes: python-dbm
Group: Trustix Official

%description modules
The main python RPM lakes some of the modules compiled from the source. 
This are the missing modules: lib-old, lib-tk, encodings, email,
compiler, hotshot, xml, curses.

%package docs
Summary: Documentation for the Python programming language.
Group: Trustix Official
Conflicts: python < %{version}

%description docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in HTML files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%package gdbm
Summary: Gnu database support for the Python programming language.
Group: Trustix Official
Requires: %{name} = %{version}
BuildRequires: gdbm-devel

%description gdbm
This is the gdbm module for Python.

Install this if you want to use the GDBM support in Python.

%package idle
Summary: IDLE is a Tkinter based IDE for Python
Group: Trustix Official
Requires: %{name} = %{version}

%description idle
IDLE is a Tkinter based Integrated Development Environment for Python.
It features a multi-window text editor with multiple undo, Python
colorizing, and many other things, as well as a Python shell window and
a debugger

%prep
%setup -q -n Python-%{version}
%patch0 -p1
%patch1 -p1
find . -name "*.nosed" -exec rm -f {} \;

echo ': ${LDSHARED='gcc -shared'}' > config.cache
echo ': ${LINKFORSHARED='-rdynamic'}' >> config.cache
echo ': ${CCSHARED='-fPIC'}' >> config.cache

cp Lib/lib-old/rand.py Lib

mkdir -p Doc
pushd Doc
   bzcat %{SOURCE1} | tar -xf -
popd

# Take care of /usr/local/bin/python
find . -type f -print0 | xargs -0 perl -pi -e 's,/usr/local/bin/python,/usr/bin/python,'

%build
OPT="$RPM_OPT_FLAGS"
CFLAGS="$RPM_OPT_FLAGS"
#MACHDEP=linux-%{_target_platform}
export OPT CFLAGS 
./configure	--host=%{_host} --target=%{_target_platform}\
   --prefix=/usr --with-threads --with-cxx=g++

LDFLAGS=-s make 

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/{bin,lib}
make install prefix=$RPM_BUILD_ROOT/usr

strip $RPM_BUILD_ROOT/usr/bin/python

# Man page
install -m 755 -d $RPM_BUILD_ROOT%{_mandir}/man1
install -m 444 Misc/python.man $RPM_BUILD_ROOT%{_mandir}/man1/python.1
rm -rf $RPM_BUILD_ROOT/usr/man/man1/python*


rm -f modules-list.full
for n in $RPM_BUILD_ROOT/usr/lib/python%{pythontopver}/*; do
  [ -d $n ] || echo $n
done >> modules-list.full

for mod in $RPM_BUILD_ROOT/usr/lib/python%{pythontopver}/lib-dynload/* ; do
  [ `basename $mod` = _tkinter.so ] || echo $mod
done >> modules-list.full
sed -e "s|$RPM_BUILD_ROOT||g" \
    -e '/dbm\.so$/d' \
    -e '/_curses.*.so$/d' < modules-list.full > modules-list

# Documentation files
find Doc/{tut,whatsnew,lib,mac,inst,dist,ref,ext,api,doc,icons} \
	-type f -and -not -regex '.*\.\(html\|css\|gif\)$' | xargs rm

%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT
rm -f modules-list modules-list.full

%files -f modules-list
%defattr(-,root,root,0755)
%{_mandir}/man1/*
/usr/bin/*
%dir /usr/lib/python%{pythontopver}
/usr/lib/python%{pythontopver}/plat-linux*
%dir /usr/lib/python%{pythontopver}/lib-dynload
/usr/lib/python%{pythontopver}/site-packages
/usr/lib/python%{pythontopver}/logging

%files devel
%defattr(-,root,root,0755)
/usr/lib/python%{pythontopver}/test
/usr/lib/python%{pythontopver}/config
/usr/lib/python%{pythontopver}/distutils
/usr/include/python%{pythontopver}

%files modules
%defattr(-,root,root,0755)
/usr/lib/python%{pythontopver}/lib-old
/usr/lib/python%{pythontopver}/lib-tk
/usr/lib/python%{pythontopver}/encodings
/usr/lib/python%{pythontopver}/email
/usr/lib/python%{pythontopver}/compiler
/usr/lib/python%{pythontopver}/hotshot
/usr/lib/python%{pythontopver}/xml
/usr/lib/python%{pythontopver}/bsddb
/usr/lib/python%{pythontopver}/curses
/usr/lib/python%{pythontopver}/lib-dynload/_curses.so
/usr/lib/python%{pythontopver}/lib-dynload/_curses_panel.so

%files docs
%defattr(-,root,root,0755)
%doc Doc/*.html Doc/{tut,whatsnew,lib,mac,inst,dist,ref,ext,api,doc,icons}

%files gdbm
%defattr(-,root,root,0755)
%dir /usr/lib/python%{pythontopver}/lib-dynload/gdbm.so

%files idle
/usr/lib/python%{pythontopver}/idlelib/*

%changelog
* Mon Oct 09 2006 Nived Gopalan <nived at trustix dot org> 2.3.5-6tr
- SECURITY FIX: Benjamin C. Wiley Sittler has reported a vulnerability
  in Python caused due to incorrect handling of UTF32/UCS-4 encoded
  strings within the "repr()" function. If an application uses the
  "repr()" function to process attacker supplied data, this can
  potentially be exploited to execute arbitrary code.

  The Common Vulnerabilities and Exposures project (cve.mitre.org)
  has assigned the name CVE-2006-4980 to this issue.

* Fri Sep 30 2005 Erlend Midttun <erlendbm at trustix dot org> 2.3.5-5tr
- Added Provides python-abi and python(abi)

* Mon Aug 29 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.3.5-4tr
- SECURITY FIX: Heap overflow in pcre_compile.c
- Integer overflow in pcre_compile.c in Perl Compatible Regular
  Expressions (PCRE) before 6.2, as used in multiple products, allows
  attackers to execute arbitrary code via quantifier values in regular
  expressions, which leads to a heap-based buffer overflow. 
- The python packages use a private copy of pcre code.

  The Common Vulnerabilities and Exposures project (cve.mitre.org)
  has assigned the name CAN-2005-2491 to this issue.

* Mon Apr 25 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.3.5-2tr
- Rebuilt against db4-4.3.27 

* Thu Apr 07 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.3.5-1tr
- New Upstream

* Fri Mar 18 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.3.4-4tr
- Rebuilt against Official Glibc-2.3.4
- Fixed Unpackages file list

* Sat Dec 04 2004 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.3.4-1tr
- New Upstream

* Fri Nov 26 2004 Erlend Midttun <erlendbm at trustix dot org> 2.2.3-14tr
- Modules require expat-libs.

* Tue Nov 10 2004 Oystein Viggen <oysteivi at trustix dot com> 2.2.3-13tr
- Rebuild with shared openssl

* Tue Oct 12 2004 Erlend Midttun <erlendbm at trustix dot org> 2.2.3-12tr
- Rebuilt

* Wed Oct 06 2004 Ajith Thampi <ajith at comodo dot com> 2.2.3-11tr
- Added PreReq /var/lib/rpm

* Mon Mar 15 2004 Chr. Toldnes <christht at trustix dot org> 2.2.3-10tr
- Added patch from upstream to fix CacheFTPHandler

* Fri Feb 27 2004 Erlend Midttun <erlendbm at trustix dot org> 2.2.3-8tr
- Need g++ again.

* Fri Dec  5 2003 Erlend Midttun <erlendbm at trustix dot org> 2.2.3-7tr
- Big rebuild

* Sat Oct  4 2003 Goetz Bock <bg at tawie dot org> 2.2.3-6bg
- fixed double include

* Thu Aug 14 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.3-5tr
- Rebuilt for cloud.

* Mon Jul 21 2003 Goetz Bock <bock at trustix dot org> 2.2.3-4bg
- added distutils and plat-linux-i586 to devel
- added new sub-package for all the other python modules

* Mon Jun 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.3-3tr
- Added %defattr.

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.3-2tr
- Big rebuild

* Sun Jun  1 2003 Gerald Dachs <gda at trustix dot org> 2.2.3-1gd
- New upstream version 2.2.3

* Thu May 15 2003 Tore Olsen <toreo at trustix dot com> 2.2.2-3to
- Added buildrequires
- Removed tools package, it contained only GUI stuff.
- Fixed doc package

* Thu Apr  3 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.2-2em
- Eh?  C++ required?

* Tue Apr  1 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.2-1em
- New upstream.

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.1-5em
- Rebuilt against glibc 2.3.2.

* Sat Jan 18 2003 Gerald Dachs <gda at trustix dot org> 2.2.1-4gd
- rebuilt against openssl 0.9.7-1gd

* Wed Jun 12 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.1-3ct
- Minor cleanup

* Mon Jun 10 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.1-2ct
- Rebuilt against better glibc.

* Fri May 31 2002 Christian H. Toldnes <christht at trustix dot com>
- Update to 2.2.1

* Wed Mar 28 2001 Alexander Reelsen <ar at trustix dot com>
- Linked against new gmp libraries in order to satisfy dependencies

* Thu Oct 26 2000 Erlend Midttun <erlendbm at trustix dot com>
- Autorebuild to link with new libraries.

* Mon May 08 2000 Oystein Viggen <oysteivi at trustix dot com>
- Remove tkinter, as there is no GUI in TSL

* Fri Sep 17 1999 Tim Powers <timp@redhat.com>
- added modulator, and pynche to the python-tools package
- using a files list in the %files section for python-tools

* Fri Sep 17 1999 Michael K. Johnson <johnsonm@redhat.com>
- added conflicts/requires between subpackages so that you cannot
  have an older tkinter installed with a new python.
- added more tools

* Wed Sep 15 1999 Michael K. Johnson <johnsonm@redhat.com>
- changed defattr so that executable scripts in docs stay executable

* Tue Aug 24 1999 Bill Nottingham <notting@redhat.com>
- rebuild to fix broken tkinter.

* Mon Aug  9 1999 Matt Wilson <msw@redhat.com>
- fixed bogus /usr/local/bin/python requirements

* Sat Jul 17 1999 Matt Wilson <msw@redhat.com>
- added patch to import global symbols until we get libtool patched

* Sun Jul 11 1999 Matt Wilson <msw@redhat.com>
- updated to 1.5.2

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 10)

* Thu Mar 18 1999 Bill Nottingham <notting@redhat.com>
- fix permissions in python-docs

* Thu Feb 11 1999 Michael Johnson <johnsonm@redhat.com>
- added mpzmodule at user request (uses gmp)
- added bsddbmodule at user request (uses db 1.85 interface)

* Mon Feb 08 1999 Michael Johnson <johnsonm@redhat.com>
- add --with-threads at user request
- clean up spec file

* Fri Jan 08 1999 Michael K. Johnson <johnsonm@redhat.com>
- New libc changes ndbm.h to db1/ndbm.h and -ldb to -ldb1

* Thu Sep  3 1998 Jeff Johnson <jbj@redhat.com>
- recompile for RH 5.2.

* Wed May 06 1998 Cristian Gafton <gafton@redhat.com>
- python-docs used to require /usr/bin/sed. Changed to /bin/sed instead

* Wed Apr 29 1998 Cristian Gafton <gafton@redhat.com>
- fixed the spec file for version 1.5.1
- buildroot (!)

* Mon Apr 20 1998 Michael K. Johnson <johnsonm@redhat.com>
- updated to python 1.5.1
- created our own Python-Doc tar file from 1.5 to substitute for the
  not-yet-released Doc package.
- build _tkinter properly
- use readline again
- build crypt module again
- install rand replacement module
- added a few modules

* Thu Apr 09 1998 Erik Troan <ewt@redhat.com>
- updated to python 1.5
- made /usr/lib/python1.5 file list automatically generated

* Tue Nov 04 1997 Michael K. Johnson <johnsonm@redhat.com>
- Fixed dependencies for python and tkinter

* Mon Nov 03 1997 Michael K. Johnson <johnsonm@redhat.com>
- pulled out tk-related stuff into tkinter package

* Fri Oct 10 1997 Erik Troan <ewt@redhat.com>
- bunches of scripts used /usr/local/bin/python instead of /usr/bin/python

* Tue Sep 30 1997 Erik Troan <ewt@redhat.com>
- updated for tcl/tk 8.0

* Thu Jul 10 1997 Erik Troan <ewt@redhat.com>
- Built on "glibc"
